const CONFIG_KEY = 'app_config';

export const defaultConfig = {
  backendUrl: '',
  authKey: '',
};

/**
 * 浏览器环境配置操作工具
 */
const ConfigTool = {
  /**
   * 从本地存储读取配置
   * @returns {{backendUrl: string, authKey: string}}
   */
  load: () => {
    try {
      const stored = localStorage.getItem(CONFIG_KEY);
      if (stored) {
        return { ...defaultConfig, ...JSON.parse(stored) };
      }
    } catch (e) {
      console.error('读取配置失败:', e);
      localStorage.removeItem(CONFIG_KEY);
    }
    return { ...defaultConfig };
  },

  /**
   * 保存配置到本地存储
   * @param {Object} config - 要保存的配置对象
   * @returns {boolean} 是否保存成功
   */
  save: (config) => {
    try {
      localStorage.setItem(CONFIG_KEY, JSON.stringify(config));
      //console.log(`正在保存配置：${JSON.stringify(config)}`);
      //console.log(`测试读取配置：${JSON.stringify(ConfigTool.load())}`);
      return true;
    } catch (e) {
      console.error('保存配置失败:', e);
      if (e.name === 'QuotaExceededError') {
        alert('存储空间不足，请清理后重试');
      }
      return false;
    }
  },

  /**
   * 清除配置
   * @returns {boolean} 是否清除成功
   */
  clear: () => {
    try {
      localStorage.removeItem(CONFIG_KEY);
      return true;
    } catch (e) {
      console.error('清除配置失败:', e);
      return false;
    }
  },

  /**
   * 获取存储标识（浏览器环境返回固定值）
   * @returns {string}
   */
  getConfigPath: () => `localStorage:${CONFIG_KEY}`,

  /**
   * 检查存储是否可用
   * @returns {boolean}
   */
  isStorageAvailable: () => {
    try {
      const testKey = 'test';
      localStorage.setItem(testKey, testKey);
      localStorage.removeItem(testKey);
      return true;
    } catch (e) {
      return false;
    }
  },
};

export default ConfigTool;
